scipy.spatial.cKDTree
=====================

.. currentmodule:: scipy.spatial

.. autoclass:: cKDTree

   

   .. HACK
      .. autosummary::
         :toctree:
      
         cKDTree.__init__
         cKDTree.query



   

   .. HACK
      .. autosummary::
         :toctree:
      
         cKDTree.data
         cKDTree.leafsize
         cKDTree.m
         cKDTree.maxes
         cKDTree.mins
         cKDTree.n

